import { useSelector } from 'react-redux';
import { Switch, Route } from "react-router-dom";
import { PrivateRoute } from './components/composed/PrivateRoute';

import { Body } from './components/layout/Body';
import { LandingPage } from './screens/LandingPage';
import { Signup } from './screens/Signup';
import { Login } from './screens/Login';
import { Header } from './components/layout/Header';
import { Activities } from './screens/Activities';
import { SortedActivities } from './screens/SortedActivities';
import { ActivityDetails } from './screens/ActivityDetails';
import { HeaderIsLogged } from './components/layout/HeaderIsLogged';
import { Footer } from './components/layout/Footer';
import { NewActivity } from './screens/NewActivity';
import { NotFound } from './screens/NotFound';
import { ActivitiesByCategory } from './screens/ActivitiesByCategory';
import { UserAccount } from './screens/UserAccount';
import { InstallationBanner } from './components/composed/InstallationBanner';

import { ThemeProvider } from '@material-ui/core/styles';
import { theme } from './assets/theme/theme';
import { PrivacyPolicy } from './screens/PrivacyPolicy';
import { LegalNotice } from './screens/LegalNotice';


export const App = () => {
  // const localStorageIsLogged = JSON.parse(localStorage.getItem('entrenemIsLogged'));
  const isLogged = useSelector(state => state.isLogged);

  return (
    <ThemeProvider theme={ theme }>
      { isLogged ? <HeaderIsLogged /> : <Header /> }
      <Body>
        <Switch>
          <Route exact path="/" component={ LandingPage } />
          <Route exact path="/registrar" component={ Signup } />
          <Route exact path="/iniciar" component={ Login } />
          <Route exact path="/politica-de-privacitat" component={ PrivacyPolicy } />
          <Route exact path="/avis-legal" component={ LegalNotice } />
          <PrivateRoute exact path="/activitats">
            <Activities />
          </PrivateRoute>
          <PrivateRoute path="/activitats/activitat-detall/:activityId">
            <ActivityDetails />
          </PrivateRoute>
          <PrivateRoute exact path="/activitats/usuari">
            <SortedActivities show="proposades" title="Activitats proposades" color />
          </PrivateRoute>
          <PrivateRoute exact path="/activitats/inscrit">
            <SortedActivities show="inscrites" title="Activitats inscrites" color />
          </PrivateRoute>
          <PrivateRoute exact path="/activitats/categoria/:category">
            <ActivitiesByCategory />
          </PrivateRoute>
          <PrivateRoute exact path="/activitats/comentat">
            <SortedActivities show="comentades" title="Activitats comentades" color />
          </PrivateRoute>
          <PrivateRoute exact path="/activitats/totes">
            <SortedActivities show="totes" title="Totes les activitats" color />
          </PrivateRoute>
          <PrivateRoute exact path="/activitats/nova-activitat">
            <NewActivity />
          </PrivateRoute>
          <PrivateRoute exact path="/usuari">
            <UserAccount />
          </PrivateRoute>
          <Route component={ NotFound } />
        </Switch>
      </Body>
      { isLogged && <Footer /> }
      <InstallationBanner />
    </ThemeProvider>
  )
};
