import Link from '../styled/Link';
import { SingleCard, GridContainer, ActivityIconBox, FlexBox, iconStyles } from './ActivityCard.styles';
import { CardContent } from '@material-ui/core';
import { Place, EventAvailable, AccessTime } from '@material-ui/icons';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { categories } from '../../utils/categories';
import { formateDate } from '../../utils/formateDate';
import PropTypes from 'prop-types';

export const ActivityCard = ({ activity }) => {
  const icons = categories;
  const icon = icons.filter(element => element.title === activity.category);
  const path = `/activitats/activitat-detall/${activity._id}`;

  const category = activity.category === 'natacio' ? 'natació' : activity.category;
  const date = formateDate(activity.date, true);

  return (
    <Link to={ path }>
      <SingleCard>
        <CardContent>
          <GridContainer>
            <div>
              <span>{ category }</span>
              <h3>{ activity.title }</h3>
            </div>
            <ActivityIconBox>
              <FontAwesomeIcon icon={ icon[0].icon } />
            </ActivityIconBox>
          </GridContainer>
          <FlexBox>
            <div>
              <Place style={ iconStyles } />
              <span>{ activity.place }</span>
            </div>
            <div>
              <EventAvailable style={ iconStyles } />
              <span>{ date }</span>
            </div>
            <div>
              <AccessTime style={ iconStyles } />
              <span>{ activity.time }</span>
            </div>
          </FlexBox>
        </CardContent>
      </SingleCard>
    </Link>
  );
};

ActivityCard.propTypes = {
  activity: PropTypes.object,
};
