import { useState } from 'react';
import { useSelector, useDispatch } from 'react-redux';
import { postCommentary } from '../../redux/actions/commentariesActions';
import PropTypes from 'prop-types';

import { TextField, IconButton, CircularProgress } from "@material-ui/core";
import { CommentaryCard, TextBox, CommentaryInput, CommentaryAuthor } from './Commentaries.styles';
import { Send } from '@material-ui/icons';
import { SuccessMessage } from './SuccessMessage';


export const Commentaries = ({ activityId }) => {
  const dispatch = useDispatch();
  const isLoading = useSelector(state => state.isLoading);
  const [commentary, setCommentary] = useState('');
  const commentaries = useSelector(state => state.commentaries.commentaries);
  const userId = useSelector(state => state.user.user._id);
  const userName = useSelector(state => state.user.user.fullName);
  const [saved, setSaved] = useState(false);

  const handleClick = (e) => {
    const newCommentary = {
      message: commentary,
      writtenBy: userId,
      writtenByName: userName,
      activityID: activityId,
    };
    dispatch(postCommentary(commentaries, newCommentary, setSaved));
    setCommentary('');
  };

  return (
    <>
      { commentaries !== undefined && commentaries.length > 0 && commentaries.map(commentary =>
        <CommentaryCard key={ commentary._id }>
          <CommentaryAuthor>Commentat per: <span>{ commentary.writtenByName }</span></CommentaryAuthor>
          <TextBox>
            <p>{ commentary.message }</p>
          </TextBox>
        </CommentaryCard>)
      }
      <form noValidate autoComplete="off">
        <CommentaryInput>
          <TextField
            id="filled-multiline-static"
            label="Deixa el teu comentari"
            multiline
            fullWidth
            rows={ 4 }
            variant="filled"
            color="secondary"
            value={ commentary }
            onChange={(e) => setCommentary(e.target.value)}
          />
          <IconButton aria-label="enviar" color="secondary" onClick={(e) => handleClick(e) }>
            { isLoading ? <CircularProgress color="secondary" size={ 16 } /> : <Send /> }
          </IconButton>
        </CommentaryInput>
      </form>
      { saved && <SuccessMessage text="S'ha guardat el comentari" style={{ zIndex: 3 }} />}
    </>
  );
};

Commentaries.propTypes = {
  activityId: PropTypes.string,
};
