import { useState } from 'react';
import { useHistory } from 'react-router-dom';
import { useDispatch } from 'react-redux';
import { activityNotNew } from '../../redux/actions';

import { SpeedDial, SpeedDialAction } from '@material-ui/lab';
import { Delete, Edit, Build } from '@material-ui/icons';
import { ModalDelete } from './ModalDelete';
import PropTypes from 'prop-types';

export const EditActivity = ({ activityId }) => {
  const history = useHistory();
  const dispatch = useDispatch();
  const [open, setOpen] = useState(false);
  const [showModal, setShowModal] = useState(false);

  const styles = {
    position: 'absolute',
    top: 140,
    right: 20,
  };

  const handleClose = () => {
    setOpen(false);
  };

  const handleOpen = () => {
    setOpen(true);
  };

  const editMethod = () => {
    dispatch(activityNotNew());
    history.push('/activitats/nova-activitat');
  };

  const deleteMethod = () => setShowModal(true);

  const actions = [
    { icon: <Edit />, name: 'Edit', method: editMethod },
    { icon: <Delete />, name: 'Delete', method: deleteMethod },
  ];

  return (
    <>
      <SpeedDial
        ariaLabel="SpeedDial example"
        style={ styles }
        icon={<Build color="secondary" />}
        onClose={ handleClose }
        onOpen={ handleOpen }
        open={ open }
        direction="down"
      >
        { actions.map((action) => (
          <SpeedDialAction
            key={ action.name }
            icon={ action.icon }
            tooltipTitle={ action.name }
            onClick={ action.method }
          />
        ))}
      </SpeedDial>
      { showModal && <ModalDelete
        activityId={ activityId }
        setOpenButtonMenu={ setOpen }
        setShowModal={ setShowModal }
        text="l'activitat"
        type="activity" />
      }
    </>
  );
};

EditActivity.propTypes = {
  activityId: PropTypes.string,
};
