import { useState, useEffect } from 'react';

import { Dialog, DialogContent, DialogContentText, DialogTitle, DialogActions, Button } from '@material-ui/core/';
import { mdiExportVariant } from '@mdi/js';
import Icon from '@mdi/react';

export const InstallationBanner = () => {
  const [showInstallMessage, setShowInstallMessage] = useState(false);
  const [open, setOpen] = useState(true);
  const title = "Instal·lar l'aplicació";

  const handleClose = () => {
    setOpen(false);
  };

  // Detects if device is on iOS
  const isIos = () => {
    const userAgent = window.navigator.userAgent.toLowerCase();
    return /iphone|ipad|ipod/.test( userAgent );
  };

  // Detects if device is in standalone mode
  const isInStandaloneMode = () => ('standalone' in window.navigator) && (window.navigator.standalone);

  useEffect(() => {
    // Checks if should display install popup notification:
    if (isIos() && !isInStandaloneMode()) setShowInstallMessage(true);
  }, []);

  return (
    <>
      { showInstallMessage
        ?  <div>
          <Dialog
            open={ open }
            onClose={ handleClose }
            aria-labelledby="responsive-dialog-title"
          >
            <DialogTitle id="responsive-dialog-title">{ title }</DialogTitle>
            <DialogContent>
              <DialogContentText>
                <span>Instal·la aquesta aplicació web al teu iPhone: premi </span>
                <Icon path={ mdiExportVariant }
                  title="Compartir"
                  size={ 1 }
                  horizontal
                  color="blue"
                />
                <span> i llavors Afegir a la pantalla d'inici</span>
              </DialogContentText>
            </DialogContent>
            <DialogActions>
              <Button onClick={ handleClose } color="secondary">OK</Button>
            </DialogActions>
          </Dialog>
        </div>
        : ''
      }
    </>
  );
};
