import { useState } from 'react';
import { useDispatch } from 'react-redux';
import { useHistory } from 'react-router-dom';
import { deleteActivity, cancelUserParticipate } from '../../redux/actions/activityActions';
import {
  Button, Dialog, DialogActions, DialogTitle
} from '@material-ui/core/';
import { SuccessMessage } from './SuccessMessage';
import { deleteUser } from '../../redux/actions/userActions';
import PropTypes from 'prop-types';

export const ModalDelete = ({ participateActivities, activityId, userId, setOpenButtonMenu, setShowModal, text, type }) => {
  const history = useHistory();
  const dispatch = useDispatch();
  const [open, setOpen] = useState(true);
  const [saved, setSaved] = useState(false);
  const textModal = `Estàs segur/a que vols eliminar ${text}?`;
  const textSuccessMessage = `S'ha eliminat ${text}`;

  const handleDelete = () => {
    if (type === 'activity') {
      dispatch(deleteActivity(activityId, history, setSaved));
      setOpenButtonMenu && setOpenButtonMenu(false);
    }

    if (type === 'account') {
      participateActivities.map(activity => cancelUserParticipate(activity._id, userId));
      dispatch(deleteUser(userId));
    }

    setOpen(false);
  };

  const handleClose = () => {
    setOpen(false);
    setOpenButtonMenu && setOpenButtonMenu(false);
    setShowModal(false);
  };

  return (
    <>
      <Dialog
        open={ open }
        onClose={ handleClose }
        aria-labelledby="alert-dialog-title"
      >
        <DialogTitle id="alert-dialog-title">{ textModal }</DialogTitle>
        <DialogActions>
          <Button variant="contained" color="secondary" onClick={ handleDelete } >
            Eliminar
          </Button>
          <Button onClick={ handleClose } color="secondary" autoFocus>
            Cancel·lar
          </Button>
        </DialogActions>
      </Dialog>
      { saved && <SuccessMessage text={ textSuccessMessage } /> }
    </>
  );
};

ModalDelete.propTypes = {
  setPlace: PropTypes.func,
  participateActivities: PropTypes.array,
  activityId: PropTypes.string,
  userId: PropTypes.string,
  setOpenButtonMenu: PropTypes.func,
  setShowModal: PropTypes.func,
  text: PropTypes.string,
  type: PropTypes.string,
};
