import { useState, useEffect } from 'react';
import { useSelector } from 'react-redux';
import { withGoogleMap, withScriptjs, GoogleMap, Marker } from 'react-google-maps';
import { MapContainer } from './ReactMap.styles';

require('dotenv').config();

const googleApiKey = process.env.REACT_APP_GOOGLE_API_KEY;

const Map = () => {
  const coords = useSelector(state => state.coords.coords);
  const [mapCoords, setMapCoords] = useState({ lat: 41.40380692113999, lng: 2.17436652671604 });

  useEffect(() => {
    if (coords !== '') {
      const lat = parseFloat(coords.lat);
      const lng = parseFloat(coords.lng);
      setMapCoords({ lat, lng });
    }
    //eslint-disable-next-line
  }, [coords]);



  return (
    <>
      <GoogleMap
          defaultZoom={ 15 }
          center={ mapCoords }
        >
          <Marker position={ mapCoords } />
        </GoogleMap>
    </>
  );
};

const MapWrapped = withScriptjs(withGoogleMap(Map));

export const ReactMap = () => {
  const [keyTry, setKeyTry] = useState(false);
  const [key, setKey] = useState(googleApiKey);

  useEffect(() => {
    if (key === "undefined") {
      setKey(googleApiKey);
      setKeyTry(!keyTry);
    }
    //eslint-disable-next-line
  }, [keyTry]);

  return (
    <MapContainer>
      <MapWrapped
        googleMapURL={ `https://maps.googleapis.com/maps/api/js?v=3.exp&libraries=geometry,drawing,places&key=${googleApiKey}` }
        loadingElement={<div style={{ height: `100%` }} />}
        containerElement={<div style={{ height: `100%` }} />}
        mapElement={<div style={{ height: `100%` }} />}
      />
    </MapContainer>
  );
};
