import { useState } from 'react';
import { useLocation } from 'react-router-dom';
import { useDispatch } from 'react-redux';
import { initialPage } from '../../redux/actions/initialPageActions';
import { logout } from '../../redux/actions/authActions';

import clsx from 'clsx';
import { makeStyles } from '@material-ui/core/styles';
import {
  Drawer, AppBar, Toolbar, List, Divider, IconButton, ListItem, ListItemIcon, ListItemText, ClickAwayListener
} from '@material-ui/core';
import { Menu, ExitToApp, Info, Home, Favorite, Chat, Assignment, ChevronLeft, Person } from '@material-ui/icons';

import logo from '../../assets/logo/logo-entrenem.svg';
import { HeaderButton } from '../units/Button';
import Link from '../styled/Link';

const drawerWidth = 290;

const useStyles = makeStyles((theme) => ({
  root: {
    display: 'flex',
  },
  appBar: {
    transition: theme.transitions.create(['margin', 'width'], {
      easing: theme.transitions.easing.sharp,
      duration: theme.transitions.duration.leavingScreen,
    }),
  },
  menuButton: {
    marginRight: theme.spacing(2),
    color: '#fff',
  },
  hide: {
    display: 'none',
  },
  drawerPaper: {
    width: drawerWidth,
  },
  drawerHeader: {
    display: 'flex',
    alignItems: 'center',
    padding: theme.spacing(0, 1),
    // necessary for content to be below app bar
    ...theme.mixins.toolbar,
    justifyContent: 'flex-end',
  },
  logo: {
    width: 140,
    margin: 'auto',

    [theme.breakpoints.up('md')]: {
      width: 180,
    }
  },
  selected: {
    "& .MuiListItem-root": {
      backgroundColor: theme.palette.secondary.light
    }
  }
}));

export const HeaderIsLogged = () => {
  const dispatch = useDispatch();
  const location = useLocation();
  const classes = useStyles();
  const [open, setOpen] = useState(false);
  const isActive = (value) => (location.pathname === value ? true : false);

  const menuOptions = [
    { text: 'Home', icon: <Home />, path: "/activitats" },
    { text: 'Activitats proposades', icon: <Assignment />, path: "/activitats/usuari" },
    { text: 'Activitats inscrites', icon: <Favorite />, path: "/activitats/inscrit" },
    { text: 'Activitats comentades', icon: <Chat />, path: "/activitats/comentat" }
  ];

  const handleDrawerOpen = () => setOpen(true);
  const handleDrawerClose = () => setOpen(false);

  const handleClick = () => {
    localStorage.removeItem('entrenemIsLogged');
    localStorage.removeItem('entrenemUser');
    dispatch(logout());
    dispatch(initialPage());
  };

  return (
    <ClickAwayListener onClickAway={ handleDrawerClose }>
      <div className={ classes.root }>
        <AppBar position="sticky" className={ classes.appBar }>
          <Toolbar>
            <IconButton
              edge="start"
              className={ clsx(classes.menuButton, open && classes.hide) }
              color="inherit"
              aria-label="open drawer"
              onClick={ handleDrawerOpen }
            >
              <Menu />
            </IconButton>
            <img src={ logo } alt="Logo d'Entrenem" className={ classes.logo } />
            <HeaderButton text="Tanca sessió" method={() => handleClick()}/>
          </Toolbar>
        </AppBar>
        <Drawer
          variant="persistent"
          anchor="left"
          open={ open }
          classes={{ paper: classes.drawerPaper, }}
        >
          <div className={ classes.drawerHeader }>
            <IconButton onClick={ handleDrawerClose }>
              <ChevronLeft />
            </IconButton>
          </div>
          <Divider />
          <List>
            { menuOptions.map((menuItem, index) => (
              <Link to={ menuItem.path } key={ index } onClick={ handleDrawerClose }>
                <ListItem
                  button
                  selected={ isActive(menuItem.path) }
                  className={{ selected: classes.selected }}
                >
                  <ListItemIcon>{ menuItem.icon }</ListItemIcon>
                  <ListItemText primary={ menuItem.text } />
                </ListItem>
              </Link>
            ))}
          </List>
          <Divider />
          <List>
            <Link to="/activitats/totes" onClick={ handleDrawerClose }>
              <ListItem
                button
                selected={ isActive('/activitats/totes') }
                className={{ selected: classes.selected }}
              >
                <ListItemIcon><Info /></ListItemIcon>
                <ListItemText primary="Totes les activitats" />
              </ListItem>
            </Link>
          </List>
          <Divider />
          <List>
            <Link to="/usuari" onClick={ handleDrawerClose }>
              <ListItem
                button
                selected={ isActive('/usuari') }
                className={{ selected: classes.selected }}
              >
                <ListItemIcon><Person /></ListItemIcon>
                <ListItemText primary="El meu perfil" />
              </ListItem>
            </Link>
          </List>
          <Divider />
          <List>
            <Link to="/" onClick={ handleClick }>
              <ListItem button>
                <ListItemIcon><ExitToApp /></ListItemIcon>
                <ListItemText primary="Tanca sessió" />
              </ListItem>
            </Link>
          </List>
        </Drawer>
      </div>
    </ClickAwayListener>
  );
}
