import { useState, useEffect } from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
import Link from '../styled/Link';
import { Breadcrumbs, Typography } from "@material-ui/core";

const StyledBreadcrumb = styled(Breadcrumbs)`
  padding-left: 30px;
  padding-top: 5px;
`;

export const Breadcrumb = ({ text, title }) => {
  const [shortTitle, setShortTitle] = useState('');

  useEffect(() => {
    if (title && title.length > 15) {
      const tempTitle = title;
      const newTempTitle = tempTitle.slice(0, 15);
      setShortTitle(newTempTitle + '...');
    } else {
      setShortTitle(title);
    }
    //eslint-disable-next-line
  }, []);

  return (
    <StyledBreadcrumb aria-label="breadcrumb">
      <Link color="inherit" to="/activitats">Activitats</Link>
      { title
      ? <Typography color="textPrimary">{ text + ' - ' + shortTitle }</Typography>
      : <Typography color="textPrimary">{ text }</Typography>
      }
    </StyledBreadcrumb>
  )
};

Breadcrumb.propTypes = {
  text: PropTypes.string,
  title: PropTypes.string
};
