import { Button, Fab } from '@material-ui/core';
import { makeStyles } from '@material-ui/core/styles';
import { Add, ArrowBack } from '@material-ui/icons';
import { Link, useHistory } from 'react-router-dom';

const useStyle = makeStyles((theme) => ({
  headerBtn: {
    textTransform: 'capitalize',
    textDecoration: 'none',
  },
  contained: {
    width: '100%',
    marginBottom: 10,
    textTransform: 'capitalize',
    boxShadow: '0 4px 4px 0 rgba(0,0,0,0.4)',

  },
  outlined: {
    width: '100%',
    marginBottom: 10,
    textTransform: 'capitalize',
    boxShadow: '0 4px 4px 0 rgba(0,0,0,0.4)',
    border: '2px solid #052049',
    '&:hover': {
      border: '2px solid #052049',
    },

  },
  link: {
    width: '100%',
    textDecoration: 'none',
    [theme.breakpoints.up('md')]: {
      width: '45%'
    }
  },
  floatingBtn: {
    position: 'fixed',
    margin: 0,
    top: 'auto',
    right: 18,
    bottom: 18,
    left: 'auto',
    zIndex: 2,
  },
  floatingBtnGoBack: {
    position: 'absolute',
    margin: 0,
    bottom: 'auto',
    left: 18,
    top: 18,
    right: 'auto',
    zIndex: 2,
  }
}));

export const HeaderButton = ({ text, method, path }) => {
  const classes = useStyle();
  return (
    <Link to={ path }>
      <Button className={ classes.headerBtn } onClick={ method }>{ text }</Button>
    </Link>
  );
};

export const ContainedButton = ({ text, ...buttonProps }) => {
  const classes = useStyle();
  return <Button variant="contained" color="secondary" className={ classes.contained } {...buttonProps}>{ text }</Button>;
};

export const LinkContainedButton = ({text, path, method, ...buttonProps }) => {
  const classes = useStyle();
  return (
    <Link to={ path } className={ classes.link }>
      <Button variant="contained" color="secondary" className={ classes.contained } onClick={ method } {...buttonProps}>{ text }</Button>
    </Link>
  )
};

export const OutlinedButton = ({ text, ...buttonProps }) => {
  const classes = useStyle();
  return <Button variant="outlined" color="secondary" className={ classes.outlined } {...buttonProps}>{ text }</Button>;
};

export const LinkOutlinedButtonLandingPage = ({ text, path, method }) => {
  const classes = useStyle();
  return (
    <Link to={ path } className={ classes.link }>
      <Button variant="outlined" color="secondary" className={ classes.outlined } onClick={ method } >{ text }</Button>
    </Link>
  )
};

export const LinkOutlinedButton = ({ text, path, ...buttonProps }) => {
  const classes = useStyle();
  return (
    <Link to={ path } style={{ textDecoration: 'none' }}>
      <Button variant="outlined" color="secondary" className={ classes.outlined } {...buttonProps}>{ text }</Button>
    </Link>
  )
};

export const FloatingButton = () => {
  const classes = useStyle();
  return (
    <Link to="/activitats/nova-activitat">
      <Fab color="secondary" aria-label="nova activitat" className={ classes.floatingBtn }>
        <Add />
      </Fab>
    </Link>
  )
};

export const FloatingButtonGoBack = () => {
  const classes = useStyle();
  const history = useHistory();
  return (
    <Button onClick={ () => history.goBack() }>
      <Fab color="secondary" aria-label="tornar" className={ classes.floatingBtnGoBack }>
        <ArrowBack />
      </Fab>
    </Button>
  )
};
