import axios from 'axios';
import { loading } from './index';

const signal = axios.CancelToken.source();

export const getAllActivities = (activities) => {
  return {
    type: 'GET_ALL_ACTIVITIES',
    payload: activities
  };
};

export const getProposedActivities = (proposedActivities) => {
  return {
    type: 'GET_PROPOSED_ACTIVITIES',
    payload: proposedActivities,
  };
};

export const getParticipateActivities = (participateActivities) => {
  return {
    type: 'GET_PARTICIPATE_ACTIVITIES',
    payload: participateActivities,
  };
};

export const getCommentedActivities = (commentedActivities) => {
  return {
    type: 'GET_COMMENTED_ACTIVITIES',
    payload: commentedActivities,
  };
};

export const getActivitiesPerCategory = (categoryActivities) => {
  return {
    type: 'GET_ACTIVITIES_PER_CATEGORY',
    payload: categoryActivities,
  };
};

export const fetchAllActivities = () => {
  return dispatch => {
    const url = 'https://entrenem.herokuapp.com/api/activities';
    dispatch(loading());

    axios.get(url, {
      cancelToken: signal.token
    })
      .then(response => {
        const allActivities = response.data;
        allActivities.map(element => element.date = new Date(element.date));
        const sortedActivities = response.data.sort((a, b) => a.date - b.date);
        dispatch(getAllActivities(sortedActivities));
        dispatch(loading());
      })
      .catch(error => {
        console.log(error);
        dispatch(loading());
      });

    // cleanup function
    return function cleanup() {
      signal.cancel();
    };
  };
};

export const fetchProposedActivities = (userId) => {
  return dispatch => {
    const url = `https://entrenem.herokuapp.com/api/activities/user/${userId}`;
    dispatch(loading());

    axios.get(url, {
      cancelToken: signal.token
    })
      .then(response => {
        dispatch(getProposedActivities(response.data));
        dispatch(loading());
      })
      .catch(error => {
        console.log(error);
        dispatch(loading());
      });

    // cleanup function
    return function cleanup() {
      signal.cancel();
    };
  };
};

export const fetchParticipateActivities = (userId) => {
  return dispatch => {
    const url = 'https://entrenem.herokuapp.com/api/activities';
    dispatch(loading());

    axios.get(url, {
      cancelToken: signal.token
    })
      .then(response => {
        const allActivities = response.data;
        const participateActivities = allActivities.filter(element => {
          if (element.participants !== null && element.participants.some(el => el.userId === userId)) return true;
          return false;
        });
        dispatch(getParticipateActivities(participateActivities));
        dispatch(loading());
      })
      .catch(error => {
        console.log(error);
        dispatch(loading());
      });

    // cleanup function
    return function cleanup() {
      signal.cancel();
    };
  };
};

export const fetchCommentedActivities = (userId) => {
  let commentaries;

  return dispatch => {
    dispatch(loading());

    const getActivitiesById = () => {
      const commentedActivities = [];

      if (commentaries.length > 0) {
        commentaries.map(commentary => {
          const activityId = commentary.activityID;
          const url = `https://entrenem.herokuapp.com/api/activities/${activityId}`;

          axios.get(url, {
            cancelToken: signal.token
          })
            .then(response => {
              commentedActivities.push(response.data[0]);
              if (commentaries.length === commentedActivities.length) dispatch(getCommentedActivities(commentedActivities));
            })
            .catch(error => {
              console.log(error);
            });
          return commentedActivities;
        });
      }
      else {
        dispatch(getCommentedActivities([]));
      }
    };


    const getCommentariesByUserId = () => {
      const url = `https://entrenem.herokuapp.com/api/commentaries/user/${userId}`;

      axios.get(url, {
        cancelToken: signal.token
      })
        .then(response => {
          commentaries = response.data;
          getActivitiesById(commentaries);
        })
        .catch(error => {
          console.log(error);
        });
    };
    getCommentariesByUserId();
    dispatch(loading());

    // cleanup function
    return function cleanup() {
      signal.cancel();
    };
  };
};

export const fetchCategoryActivities = (category) => {
  return dispatch => {
    const url = `https://entrenem.herokuapp.com/api/activities/category/${category}`;
    dispatch(loading());

    axios.get(url, {
      cancelToken: signal.token
    })
      .then(response => {
        dispatch(getActivitiesPerCategory(response.data));
        dispatch(loading());
      })
      .catch(error => {
        console.log(error);
        dispatch(loading());
      });

    //cleanup function
    return function cleanup() {
      signal.cancel();
    };
  };
};
