import axios from 'axios';
import { loading } from './index';
import { activityIsNew } from './index';

const signal = axios.CancelToken.source();

export const setActivityDetails = activity => {
  return {
    type: 'SET_ACTIVITY_DETAILS',
    payload: activity
  };
};

export const setNewActivity = (activity, userId, userName, history, setSaved, setErrors) => {
  return dispatch => {
    dispatch(loading());
    setErrors({});

    const url = `https://entrenem.herokuapp.com/api/activities`;
    const config = {
      headers: {
        'Content-Type': 'application/x-www-form-urlencoded'
      }
    };

    const params = new URLSearchParams()
    params.append('category', activity.category);
    params.append('title', activity.title);
    params.append('date', activity.date);
    params.append('time', activity.time);
    params.append('place', activity.place);
    params.append('longPlace', activity.longPlace);
    params.append('description', activity.description);
    params.append('createdBy', userId);
    params.append('createdByName', userName);
    params.append('lat', activity.lat);
    params.append('lng', activity.lng);

    axios.post(url, params, config, {
      cancelToken: signal.token
    })
      .then((response) => {
        setSaved(true);
        setTimeout(() => {
          setSaved(false);
          dispatch(loading());
          dispatch(setActivityDetails({}));
          history.push("/activitats/usuari");
        }, 2000);
      })
      .catch((error) => {
        console.log(error.response.data);
        setErrors(error.response.data);
        dispatch(loading());
      });
  }
};


export const setModifiedActivity = (activity, activityId, userId, userName, history, setSaved, setErrors) => {
  return dispatch => {
    dispatch(loading());
    setErrors({});

    const url = `https://entrenem.herokuapp.com/api/activities/${activityId}`;
    const config = {
      headers: {
        'Content-Type': 'application/x-www-form-urlencoded'
      }
    };

    const params = new URLSearchParams()
    params.append('category', activity.category);
    params.append('title', activity.title);
    params.append('date', activity.date);
    params.append('time', activity.time);
    params.append('place', activity.place);
    params.append('longPlace', activity.longPlace);
    params.append('description', activity.description);
    params.append('createdBy', userId);
    params.append('createdByName', userName);
    params.append('lat', activity.lat);
    params.append('lng', activity.lng);

    axios.put(url, params, config, {
      cancelToken: signal.token
    })
      .then((response) => {
        setSaved(true);
        setTimeout(() => {
          setSaved(false);
          dispatch(activityIsNew());
          dispatch(loading());
          history.push("/activitats/usuari");
        }, 2000);
      })
      .catch((error) => {
        console.log(error.response.data);
        setErrors(error.response.data);
        dispatch(loading());
      });
  }
};

export const deleteActivity = (activityId, history, setSaved) => {
  return dispatch => {
    const url = `https://entrenem.herokuapp.com/api/activities/${activityId}`;
    const config = {
      headers: {
        'Content-Type': 'application/x-www-form-urlencoded'
      }
    };

    axios.delete(url, config, {
      cancelToken: signal.token
    })
      .then((response) => {
        setSaved(true);
        setTimeout(() => {
          setSaved(false);
          console.log(response);
          dispatch(setActivityDetails({}));
          history.push("/activitats/usuari");
        }, 2000);
      })
      .catch((error) => {
        console.log(error);
      });
  }
};

export const setUserParticipate = (activityId, userId, userName) => {
  const url = `https://entrenem.herokuapp.com/api/activities/add_participant/${activityId}/${userId}/${userName}`;
  const config = {
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded'
    }
  };

  axios.patch(url, config, {
    cancelToken: signal.token
  })
    .then((response) => {
      console.log(response);
    })
    .catch((error) => {
      console.log(error);
    });
};

export const cancelUserParticipate = (activityId, userId, userName) => {
  const url = `https://entrenem.herokuapp.com/api/activities/delete_participant/${activityId}/${userId}/${userName}`;
  const config = {
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded'
    }
  };

  axios.patch(url, config, {
    cancelToken: signal.token
  })
    .then((response) => {
      console.log(response);
    })
    .catch((error) => {
      console.log(error);
    });
};
