import axios from 'axios';
import { loading } from '../actions';
import { login, logout } from '../actions/authActions';
import { initialPage } from './initialPageActions';

export const setUser = user => {
  return {
    type: 'SET_USER',
    payload: user
  };
};

export const modifyUser = user => {
  return {
    type: 'MODIFY_USER',
    payload: user
  };
};

export const fetchUser = (user, history, setErrors) => {
  const signal = axios.CancelToken.source();

  return dispatch => {
    dispatch(loading());
    setErrors({});

    // API Call with axios
    const url = 'https://entrenem.herokuapp.com/api/users/iniciar';
    const config = {
      headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
    };

    const params = new URLSearchParams()
    params.append('fullName', user.fullName);
    params.append('email', user.email);
    params.append('password', user.password);

    axios.post(url, params, config, {
      cancelToken: signal.token
    })
      .then((response) => {
        dispatch(setUser(response.data.user));
        localStorage.setItem('entrenemUser', JSON.stringify(response.data.user));
        dispatch(loading());
        dispatch(login());
        localStorage.setItem('entrenemIsLogged', JSON.stringify({ isLogged: true }));
        history.push("/activitats");
      })
      .catch(error => {
        if (error.response.status === 400) {
          console.log('error.response.data', error.response.data);
          setErrors(error.response.data);
          dispatch(loading());
        }
        if (error.response.status === 404) {
          setErrors({email: 'L\'usuari no existeix'});
          dispatch(loading());
        }
      });
  };
};

export const deleteUser = (userId) => {
  const signal = axios.CancelToken.source();

  return dispatch => {
    const url = `https://entrenem.herokuapp.com/api/users/${userId}`;
    const config = {
      headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
    };

    axios.delete(url, config, {
      cancelToken: signal.token
    })
      .then((response) => {
        localStorage.removeItem('entrenemIsLogged');
        localStorage.removeItem('entrenemUser');
        dispatch(logout());
        dispatch(initialPage());
      })
      .catch(error => {
        console.log(error);
      });
  };
};
