import { useState } from 'react';
import { useHistory } from 'react-router-dom';
import { useDispatch, useSelector } from 'react-redux';
import { fetchUser } from '../redux/actions/userActions';

import {
  TextField, Checkbox, Container, InputAdornment, IconButton, CircularProgress
} from '@material-ui/core';
import { Lock, Visibility, VisibilityOff } from '@material-ui/icons';
import { ContainedButton, LinkOutlinedButton } from '../components/units/Button';
import { TitleSection } from '../components/styled/TitleSection';
import { DivBox, Icon, Label, checkLabel, DividerLine, GridDiv, flexBox, btn } from './Login.Signup.styles';
import { Copyright } from '../components/composed/Copyright';


export const Login = () => {
  const dispatch = useDispatch();
  const isLoading = useSelector(state => state.isLoading);
  const history = useHistory();
  const [email, setEmail] = useState('');
  const [password, setPassword] = useState('');
  const [showPassword, setShowPassword] = useState(false);
  const [errors, setErrors] = useState({});
  const [checked, setChecked] = useState(true);

  const handlePasswordVisibility = () => {
    setShowPassword(!showPassword);
  };

  const handleMouseDownPassword = (e) => {
    e.preventDefault();
  };

  const handleChange = (e) => {
    setChecked(e.target.checked);
  };

  const handleSubmit = (e) => {
    e.preventDefault();
    const user = { 'email': email, 'password': password };
    dispatch(fetchUser(user, history, setErrors));
  };

  return (
    <DivBox>
      <Container maxWidth="xs">
        <div style={ flexBox }>
          <Icon><Lock /></Icon>
          <TitleSection>Inicia sessió</TitleSection>
          <form noValidate autoComplete="off">
            <TextField
              variant="outlined"
              margin="normal"
              required
              fullWidth
              id="email"
              label="Correu electrònic"
              name="email"
              autoComplete="email"
              autoFocus
              color="secondary"
              value={ email }
              onChange={(e) => setEmail(e.target.value)}
              error={ errors.email !== undefined }
              helperText={ errors.email }
            />
            <TextField
              variant="outlined"
              margin="normal"
              required
              fullWidth
              name="password"
              label="Paraula de pas"
              type={ showPassword ? 'text' : 'password' }
              value={ password.password }
              onChange={(e) => setPassword(e.target.value)}
              id="password"
              color="secondary"
              error={ errors.password !== undefined }
              helperText={ errors.password }
              InputProps={{
                endAdornment: (
                  <InputAdornment position='end'>
                    <IconButton
                      aria-label='toggle password visibility'
                      onClick={ handlePasswordVisibility }
                      onMouseDown={ handleMouseDownPassword }
                    >
                      { showPassword ? <Visibility /> : <VisibilityOff /> }
                    </IconButton>
                  </InputAdornment>
                ),
              }}
            />
            <Label
              control={<Checkbox value="accept" color="secondary" />}
              label={ <span style={ checkLabel }>Recorda'm</span> }
              checked={ checked }
              onChange={ handleChange }
            />
            <ContainedButton
              type="submit"
              text="Inicia sessió"
              startIcon={ isLoading && <CircularProgress color="primary" /> }
              onClick={ handleSubmit }
            />
            <DividerLine />
            <GridDiv>
              <span>No tens compte?</span>
              <LinkOutlinedButton text="Registra't" path="/registrar" style={ btn } />
            </GridDiv>
          </form>
        </div>
      <Copyright  />
      </Container>
    </DivBox>
  );
};
