import { useState, useEffect } from 'react';
import { useSelector, useDispatch } from 'react-redux';
import { fetchProposedActivities, fetchParticipateActivities, fetchCommentedActivities } from '../redux/actions/activitiesActions';

import { Body } from '../components/layout/Body';
import { TitleSection } from '../components/styled/TitleSection';
import { FloatingButton } from '../components/units/Button';
import Link from '../components/styled/Link';
import { ModalDelete } from '../components/composed/ModalDelete';

import { Button } from "@material-ui/core";
import { Icon, bigIcon, smallIcons, UserInfoCard, DividerLine, bottomPadding } from './UserAccount.styles';
import { Person, Favorite, Chat, Assignment } from '@material-ui/icons';

import { formateDate } from '../utils/formateDate';


export const UserAccount = () => {
  const dispatch = useDispatch();
  const user = useSelector(state => state.user.user);
  const userId = user._id;
  const userName = user.fullName;
  const proposedActivities = useSelector(state => state.activities.proposedActivities);
  const participateActivities = useSelector(state => state.activities.participateActivities);
  const commentedActivities = useSelector(state => state.activities.commentedActivities);
  const [showModal, setShowModal] = useState(false);
  const registered = formateDate(user.date, false);

  useEffect(() => {
    dispatch(fetchProposedActivities(userId));
    dispatch(fetchParticipateActivities(userId));
    dispatch(fetchCommentedActivities(userId));
    //eslint-disable-next-line
  }, []);



  return (
    <Body>
      <FloatingButton />
      <Icon><Person style={ bigIcon } /></Icon>
      <TitleSection>El meu perfil</TitleSection>
      <UserInfoCard>
          <p>Nom d'usuari: { userName }</p>
          <p>Registrat el dia: { registered }</p>
          <DividerLine />
          <p>
            <Assignment style={ smallIcons } />
            <Link to="/activitats/usuari">Activitats proposades:</Link>
            { ' ' }
            { proposedActivities.length }
          </p>
          <p>
            <Favorite style={ smallIcons } />
            <Link to="/activitats/inscrit">Activitats inscrites:</Link>
            { ' ' }
            { participateActivities.length }
          </p>
          <p>
            <Chat style={ smallIcons } />
            <Link to="/activitats/comentat">Activitats comentades:</Link>
            { ' ' }
            { commentedActivities.length }
          </p>
          <DividerLine />
          <Button onClick={() => setShowModal(true)} color="secondary" style={ bottomPadding }>Eliminar el meu compte</Button>
      </UserInfoCard>
      { showModal && <ModalDelete
        participateActivities={ participateActivities }
        userId={ userId }
        setShowModal={ setShowModal }
        text="el compte"
        type="account" />
      }
    </Body>
  );
};
