/* eslint-disable no-restricted-globals */

// This service worker can be customized!
// See https://developers.google.com/web/tools/workbox/modules
// for the list of available Workbox modules, or add any other
// code you'd like.
// You can also remove this file if you'd prefer not to use a
// service worker, and the Workbox build step will be skipped.

import { clientsClaim } from 'workbox-core';
import { ExpirationPlugin } from 'workbox-expiration';
import { precacheAndRoute, createHandlerBoundToURL } from 'workbox-precaching';
import { registerRoute } from 'workbox-routing';
import { StaleWhileRevalidate } from 'workbox-strategies';

clientsClaim();

// Precache all of the assets generated by your build process.
// Their URLs are injected into the manifest variable below.
// This variable must be present somewhere in your service worker file,
// even if you decide not to use precaching. See https://cra.link/PWA
precacheAndRoute(self.__WB_MANIFEST);

// Set up App Shell-style routing, so that all navigation requests
// are fulfilled with your index.html shell. Learn more at
// https://developers.google.com/web/fundamentals/architecture/app-shell
const fileExtensionRegexp = new RegExp('/[^/?]+\\.[^/]+$');
registerRoute(
  // Return false to exempt requests from being fulfilled by index.html.
  ({ request, url }) => {
    // If this isn't a navigation, skip.
    if (request.mode !== 'navigate') {
      return false;
    } // If this is a URL that starts with /_, skip.

    if (url.pathname.startsWith('/_')) {
      return false;
    } // If this looks like a URL for a resource, because it contains // a file extension, skip.

    if (url.pathname.match(fileExtensionRegexp)) {
      return false;
    } // Return true to signal that we want to use the handler.

    return true;
  },
  createHandlerBoundToURL(process.env.PUBLIC_URL + '/index.html')
);

// An example runtime caching route for requests that aren't handled by the
// precache, in this case same-origin .png requests like those from in public/
registerRoute(
  // Add in any other file extensions or routing criteria as needed.
  ({ url }) => url.origin === self.location.origin && url.pathname.endsWith('.png'), // Customize this strategy as needed, e.g., by changing to CacheFirst.
  new StaleWhileRevalidate({
    cacheName: 'images',
    plugins: [
      // Ensure that once this runtime cache reaches a maximum size the
      // least-recently used images are removed.
      new ExpirationPlugin({ maxEntries: 50 }),
    ],
  })
);

// This allows the web app to trigger skipWaiting via
// registration.waiting.postMessage({type: 'SKIP_WAITING'})
self.addEventListener('message', (event) => {
  if (event.data && event.data.type === 'SKIP_WAITING') {
    self.skipWaiting();
  }
});

// Any other custom service worker logic can go here.

const preCacheName = "pre-cache-pra",
  preCacheFiles = [
    "/",
    "/public/index.html",
    "/public/favicon.ico",
    "/public/logo192.png",
    "/public/logo512.png",
    "/public/maskable_icon_x192.png",
    "/src/assets/logo/logo-entrenem.svg",
    "/src/assets/logo/logo-icon.svg",
    "/src/assets/logo/logo-entrenem.png",
    "/src/assets/img/running-lg.png",
    "/src/assets/theme/theme.js",
    "/src/utils/categories.js",
    "/src/utils/formateDate.js",
    "/src/utils/getCoordinates.js",
    "/src/utils/iconsActivity.js",
    "/index.css",
    "/src/components/layout/Footer.js",
    "/src/components/composed/ActivitiesList.styles.js",
    "/src/components/composed/ActivityCard.styles.js",
    "/src/components/composed/Commentaries.styles.js",
    "/src/components/composed/ReactMap.styles.js",
    "/src/components/composed/SuccessMessage.styles.js",
    "/src/screens/NotFound.js",
    "/src/screens/Activities.styles.js",
    "/src/screens/ActivityDetails.styles.js",
    "/src/screens/LandingPage.styles.js",
    "/src/screens/Login.Signup.styles.js",
    "/src/screens/NewActivity.styles.js",
    "/src/screens/SortedActivities.styles.js",
    "/src/screens/UserAccount.styles.js",
    "https://fonts.googleapis.com/css?family=Roboto:300,400,500,700&display=swap",
    "https://fonts.googleapis.com/icon?family=Material+Icons"
  ];

self.addEventListener("install", event => {
  console.log("installing precached files");
  caches.open(preCacheName).then(function (cache) {
    return cache.addAll(preCacheFiles);
  })
});

self.addEventListener("activate", event => {
  self.clients.claim();
});

self.addEventListener("fetch", event => {
  event.respondWith(
    caches.match(event.request).then(response => {
      if (!response) {
        //fall back to the network fetch
        return fetch(event.request);
      }
      return response;
    })
  )
});

